import abc
import enum
from abc import ABC
from datetime import (
    date as _date,
    datetime as _datetime,
    time as _time,
    timedelta as _timedelta,
)
from typing import ClassVar, Literal, TypeVar, final, overload

__all__ = [
    "Date",
    "Time",
    "UTCDateTime",
    "OffsetDateTime",
    "ZonedDateTime",
    "LocalSystemDateTime",
    "NaiveDateTime",
    "DateDelta",
    "TimeDelta",
    "DateTimeDelta",
    "years",
    "months",
    "weeks",
    "days",
    "hours",
    "minutes",
    "seconds",
    "microseconds",
    "SkippedTime",
    "AmbiguousTime",
    "InvalidOffset",
    "MONDAY",
    "TUESDAY",
    "WEDNESDAY",
    "THURSDAY",
    "FRIDAY",
    "SATURDAY",
    "SUNDAY",
]

class _UNSET: ...

_TDateTime = TypeVar("_TDateTime")
Disambiguate = Literal["raise", "earlier", "later", "compatible"]

@final
class Date:
    def __init__(self, year: int, month: int, day: int) -> None: ...
    MIN: ClassVar[Date]
    MAX: ClassVar[Date]
    @property
    def year(self) -> int: ...
    @property
    def month(self) -> int: ...
    @property
    def day(self) -> int: ...
    def day_of_week(self) -> Weekday: ...
    def at(self, t: Time, /) -> NaiveDateTime: ...
    def py_date(self) -> _date: ...
    @classmethod
    def from_py_date(cls, d: _date, /) -> Date: ...
    def format_common_iso(self) -> str: ...
    @classmethod
    def parse_common_iso(cls, s: str, /) -> Date: ...
    def replace(
        self,
        *,
        year: int | _UNSET = ...,
        month: int | _UNSET = ...,
        day: int | _UNSET = ...,
    ) -> Date: ...
    def add(
        self, *, years: int = 0, months: int = 0, weeks: int = 0, days: int = 0
    ) -> Date: ...
    def subtract(
        self, *, years: int = 0, months: int = 0, weeks: int = 0, days: int = 0
    ) -> Date: ...
    def __add__(self, p: DateDelta) -> Date: ...
    @overload
    def __sub__(self, d: DateDelta) -> Date: ...
    @overload
    def __sub__(self, d: Date) -> DateDelta: ...
    def __lt__(self, other: Date) -> bool: ...
    def __le__(self, other: Date) -> bool: ...
    def __gt__(self, other: Date) -> bool: ...
    def __ge__(self, other: Date) -> bool: ...
    def __hash__(self) -> int: ...

@final
class Time:
    def __init__(
        self,
        hour: int = 0,
        minute: int = 0,
        second: int = 0,
        *,
        nanosecond: int = 0,
    ) -> None: ...
    MIDNIGHT: ClassVar[Time]
    NOON: ClassVar[Time]
    MAX: ClassVar[Time]
    @property
    def hour(self) -> int: ...
    @property
    def minute(self) -> int: ...
    @property
    def second(self) -> int: ...
    @property
    def nanosecond(self) -> int: ...
    def on(self, d: Date) -> NaiveDateTime: ...
    def py_time(self) -> _time: ...
    @classmethod
    def from_py_time(cls, t: _time, /) -> Time: ...
    def format_common_iso(self) -> str: ...
    @classmethod
    def parse_common_iso(cls, s: str, /) -> Time: ...
    def replace(
        self,
        *,
        hour: int | _UNSET = ...,
        minute: int | _UNSET = ...,
        second: int | _UNSET = ...,
        nanosecond: int | _UNSET = ...,
    ) -> Time: ...
    def __lt__(self, other: Time) -> bool: ...
    def __le__(self, other: Time) -> bool: ...
    def __gt__(self, other: Time) -> bool: ...
    def __ge__(self, other: Time) -> bool: ...
    def __hash__(self) -> int: ...

@final
class TimeDelta:
    def __init__(
        self,
        *,
        hours: float = 0,
        minutes: float = 0,
        seconds: float = 0,
        milliseconds: float = 0,
        microseconds: float = 0,
        nanoseconds: int = 0,
    ) -> None: ...
    ZERO: ClassVar[TimeDelta]
    MAX: ClassVar[TimeDelta]
    MIN: ClassVar[TimeDelta]
    def in_days_of_24h(self) -> float: ...
    def in_hours(self) -> float: ...
    def in_minutes(self) -> float: ...
    def in_seconds(self) -> float: ...
    def in_milliseconds(self) -> float: ...
    def in_microseconds(self) -> float: ...
    def in_nanoseconds(self) -> int: ...
    def in_hrs_mins_secs_nanos(self) -> tuple[int, int, int, int]: ...
    def py_timedelta(self) -> _timedelta: ...
    @classmethod
    def from_py_timedelta(cls, td: _timedelta, /) -> TimeDelta: ...
    def format_common_iso(self) -> str: ...
    @classmethod
    def parse_common_iso(cls, s: str, /) -> TimeDelta: ...
    def __hash__(self) -> int: ...
    def __lt__(self, other: TimeDelta) -> bool: ...
    def __le__(self, other: TimeDelta) -> bool: ...
    def __gt__(self, other: TimeDelta) -> bool: ...
    def __ge__(self, other: TimeDelta) -> bool: ...
    def __bool__(self) -> bool: ...
    def __add__(self, other: TimeDelta) -> TimeDelta: ...
    def __sub__(self, other: TimeDelta) -> TimeDelta: ...
    def __mul__(self, other: float) -> TimeDelta: ...
    def __rmul__(self, other: float) -> TimeDelta: ...
    def __neg__(self) -> TimeDelta: ...
    def __pos__(self) -> TimeDelta: ...
    @overload
    def __truediv__(self, other: float) -> TimeDelta: ...
    @overload
    def __truediv__(self, other: TimeDelta) -> float: ...
    def __abs__(self) -> TimeDelta: ...

@final
class DateDelta:
    ZERO: ClassVar[DateDelta]
    def __init__(
        self, *, years: int = 0, months: int = 0, weeks: int = 0, days: int = 0
    ) -> None: ...
    @property
    def years(self) -> int: ...
    @property
    def months(self) -> int: ...
    @property
    def weeks(self) -> int: ...
    @property
    def days(self) -> int: ...
    def in_months_days(self) -> tuple[int, int]: ...
    def in_years_months_days(self) -> tuple[int, int, int]: ...
    def format_common_iso(self) -> str: ...
    @classmethod
    def parse_common_iso(cls, s: str, /) -> DateDelta: ...
    def replace(
        self,
        *,
        years: int | _UNSET = ...,
        months: int | _UNSET = ...,
        weeks: int | _UNSET = ...,
        days: int | _UNSET = ...,
    ) -> DateDelta: ...
    def __hash__(self) -> int: ...
    def __bool__(self) -> bool: ...
    def __neg__(self) -> DateDelta: ...
    def __pos__(self) -> DateDelta: ...
    def __mul__(self, other: int) -> DateDelta: ...
    def __rmul__(self, other: int) -> DateDelta: ...
    @overload
    def __add__(self, other: DateDelta) -> DateDelta: ...
    @overload
    def __add__(self, other: TimeDelta) -> DateTimeDelta: ...
    def __radd__(self, other: TimeDelta) -> DateTimeDelta: ...
    @overload
    def __sub__(self, other: DateDelta) -> DateDelta: ...
    @overload
    def __sub__(self, other: TimeDelta) -> DateTimeDelta: ...
    def __rsub__(self, other: TimeDelta) -> DateTimeDelta: ...
    def __abs__(self) -> DateDelta: ...

@final
class DateTimeDelta:
    def __init__(
        self,
        *,
        years: int = 0,
        months: int = 0,
        weeks: int = 0,
        days: int = 0,
        hours: float = 0,
        minutes: float = 0,
        seconds: float = 0,
        milliseconds: float = 0,
        microseconds: float = 0,
        nanoseconds: int = 0,
    ) -> None: ...
    ZERO: ClassVar[DateTimeDelta]
    def date_part(self) -> DateDelta: ...
    def time_part(self) -> TimeDelta: ...
    def in_months_days_secs_nanos(self) -> tuple[int, int, int, int]: ...
    def format_common_iso(self) -> str: ...
    @classmethod
    def parse_common_iso(cls, s: str, /) -> DateTimeDelta: ...
    def __eq__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def __bool__(self) -> bool: ...
    def __add__(self, other: Delta) -> DateTimeDelta: ...
    def __radd__(self, other: TimeDelta | DateDelta) -> DateTimeDelta: ...
    def __sub__(
        self, other: DateTimeDelta | TimeDelta | DateDelta
    ) -> DateTimeDelta: ...
    def __rsub__(self, other: TimeDelta | DateDelta) -> DateTimeDelta: ...
    def __mul__(self, other: int) -> DateTimeDelta: ...
    def __rmul__(self, other: int) -> DateTimeDelta: ...
    def __neg__(self) -> DateTimeDelta: ...
    def __pos__(self) -> DateTimeDelta: ...
    def __abs__(self) -> DateTimeDelta: ...

Delta = DateTimeDelta | TimeDelta | DateDelta

class _DateTime(ABC):
    @property
    def year(self) -> int: ...
    @property
    def month(self) -> int: ...
    @property
    def day(self) -> int: ...
    @property
    def hour(self) -> int: ...
    @property
    def minute(self) -> int: ...
    @property
    def second(self) -> int: ...
    @property
    def nanosecond(self) -> int: ...
    def date(self) -> Date: ...
    def time(self) -> Time: ...
    def py_datetime(self) -> _datetime: ...
    def format_common_iso(self) -> str: ...
    def __hash__(self) -> int: ...

class _AwareDateTime(_DateTime, metaclass=abc.ABCMeta):
    def to_utc(self) -> UTCDateTime: ...
    @overload
    def to_fixed_offset(self) -> OffsetDateTime: ...
    @overload
    def to_fixed_offset(
        self, offset: int | TimeDelta, /
    ) -> OffsetDateTime: ...
    def to_tz(self, tz: str, /) -> ZonedDateTime: ...
    def to_local_system(self) -> LocalSystemDateTime: ...
    def naive(self) -> NaiveDateTime: ...
    def timestamp(self) -> int: ...
    def timestamp_millis(self) -> int: ...
    def timestamp_nanos(self) -> int: ...
    def __lt__(self, other: _AwareDateTime) -> bool: ...
    def __le__(self, other: _AwareDateTime) -> bool: ...
    def __gt__(self, other: _AwareDateTime) -> bool: ...
    def __ge__(self, other: _AwareDateTime) -> bool: ...

@final
class UTCDateTime(_AwareDateTime):
    def __init__(
        self,
        year: int,
        month: int,
        day: int,
        hour: int = 0,
        minute: int = 0,
        second: int = 0,
        *,
        nanosecond: int = 0,
    ) -> None: ...
    MIN: ClassVar[UTCDateTime]
    MAX: ClassVar[UTCDateTime]
    offset: ClassVar[TimeDelta]
    @classmethod
    def now(cls) -> UTCDateTime: ...
    @classmethod
    def from_timestamp(cls, i: int, /) -> UTCDateTime: ...
    @classmethod
    def from_timestamp_millis(cls, i: int, /) -> UTCDateTime: ...
    @classmethod
    def from_timestamp_nanos(cls, i: int, /) -> UTCDateTime: ...
    @classmethod
    def from_py_datetime(cls, d: _datetime, /) -> UTCDateTime: ...
    @classmethod
    def strptime(cls, s: str, fmt: str, /) -> UTCDateTime: ...
    def format_rfc2822(self) -> str: ...
    @classmethod
    def parse_rfc2822(cls, s: str, /) -> UTCDateTime: ...
    def format_rfc3339(self) -> str: ...
    @classmethod
    def parse_rfc3339(cls, s: str, /) -> UTCDateTime: ...
    @classmethod
    def parse_common_iso(cls, s: str, /) -> UTCDateTime: ...
    def exact_eq(self, other: UTCDateTime, /) -> bool: ...
    def replace(
        self,
        *,
        year: int | _UNSET = ...,
        month: int | _UNSET = ...,
        day: int | _UNSET = ...,
        hour: int | _UNSET = ...,
        minute: int | _UNSET = ...,
        second: int | _UNSET = ...,
        nanosecond: int | _UNSET = ...,
    ) -> UTCDateTime: ...
    def replace_date(self, date: Date, /) -> UTCDateTime: ...
    def replace_time(self, time: Time, /) -> UTCDateTime: ...
    def add(
        self,
        *,
        years: int = 0,
        months: int = 0,
        weeks: int = 0,
        days: int = 0,
        hours: float = 0,
        minutes: float = 0,
        seconds: float = 0,
        milliseconds: float = 0,
        microseconds: float = 0,
        nanoseconds: int = 0,
    ) -> UTCDateTime: ...
    def subtract(
        self,
        *,
        years: int = 0,
        months: int = 0,
        weeks: int = 0,
        days: int = 0,
        hours: float = 0,
        minutes: float = 0,
        seconds: float = 0,
        milliseconds: float = 0,
        microseconds: float = 0,
        nanoseconds: int = 0,
    ) -> UTCDateTime: ...
    def __add__(self, delta: Delta) -> UTCDateTime: ...
    @overload
    def __sub__(self, other: _AwareDateTime) -> TimeDelta: ...
    @overload
    def __sub__(self, other: Delta) -> UTCDateTime: ...

@final
class OffsetDateTime(_AwareDateTime):
    def __init__(
        self,
        year: int,
        month: int,
        day: int,
        hour: int = 0,
        minute: int = 0,
        second: int = 0,
        *,
        nanosecond: int = 0,
        offset: int | TimeDelta,
    ) -> None: ...
    @property
    def offset(self) -> TimeDelta: ...
    @classmethod
    def now(cls, offset: int | TimeDelta, /) -> OffsetDateTime: ...
    @classmethod
    def from_timestamp(
        cls, i: int, /, *, offset: int | TimeDelta
    ) -> OffsetDateTime: ...
    @classmethod
    def from_timestamp_millis(
        cls, i: int, /, *, offset: int | TimeDelta
    ) -> OffsetDateTime: ...
    @classmethod
    def from_timestamp_nanos(
        cls, i: int, /, *, offset: int | TimeDelta
    ) -> OffsetDateTime: ...
    @classmethod
    def from_py_datetime(cls, d: _datetime, /) -> OffsetDateTime: ...
    @classmethod
    def strptime(cls, s: str, fmt: str, /) -> OffsetDateTime: ...
    def format_rfc2822(self) -> str: ...
    @classmethod
    def parse_rfc2822(cls, s: str, /) -> OffsetDateTime: ...
    def format_rfc3339(self) -> str: ...
    @classmethod
    def parse_rfc3339(cls, s: str, /) -> OffsetDateTime: ...
    @classmethod
    def parse_common_iso(cls, s: str, /) -> OffsetDateTime: ...
    def exact_eq(self, other: OffsetDateTime, /) -> bool: ...
    def replace(
        self,
        *,
        year: int | _UNSET = ...,
        month: int | _UNSET = ...,
        day: int | _UNSET = ...,
        hour: int | _UNSET = ...,
        minute: int | _UNSET = ...,
        second: int | _UNSET = ...,
        nanosecond: int | _UNSET = ...,
        offset: int | TimeDelta | _UNSET = ...,
    ) -> OffsetDateTime: ...
    def replace_date(self, d: Date) -> OffsetDateTime: ...
    def replace_time(self, t: Time) -> OffsetDateTime: ...
    def __sub__(self, other: _AwareDateTime) -> TimeDelta: ...

@final
class ZonedDateTime(_AwareDateTime):
    def __init__(
        self,
        year: int,
        month: int,
        day: int,
        hour: int = 0,
        minute: int = 0,
        second: int = 0,
        *,
        nanosecond: int = 0,
        tz: str,
        disambiguate: Disambiguate = "raise",
    ) -> None: ...
    @property
    def tz(self) -> str: ...
    @property
    def offset(self) -> TimeDelta: ...
    def is_ambiguous(self) -> bool: ...
    @classmethod
    def now(cls, tz: str, /) -> ZonedDateTime: ...
    @classmethod
    def from_py_datetime(cls, d: _datetime, /) -> ZonedDateTime: ...
    @classmethod
    def from_timestamp(cls, i: int, /, *, tz: str) -> ZonedDateTime: ...
    @classmethod
    def from_timestamp_millis(cls, i: int, /, *, tz: str) -> ZonedDateTime: ...
    @classmethod
    def from_timestamp_nanos(cls, i: int, /, *, tz: str) -> ZonedDateTime: ...
    @classmethod
    def parse_common_iso(cls, s: str, /) -> ZonedDateTime: ...
    def exact_eq(self, other: ZonedDateTime, /) -> bool: ...
    def replace(
        self,
        *,
        year: int | _UNSET = ...,
        month: int | _UNSET = ...,
        day: int | _UNSET = ...,
        hour: int | _UNSET = ...,
        minute: int | _UNSET = ...,
        second: int | _UNSET = ...,
        nanosecond: int | _UNSET = ...,
        tz: str | _UNSET = ...,
        disambiguate: Disambiguate | _UNSET = ...,
    ) -> ZonedDateTime: ...
    def replace_date(
        self, d: Date, /, *, disambiguate: Disambiguate = "raise"
    ) -> ZonedDateTime: ...
    def replace_time(
        self, t: Time, /, *, disambiguate: Disambiguate = "raise"
    ) -> ZonedDateTime: ...
    def add(
        self,
        *,
        years: int = 0,
        months: int = 0,
        weeks: int = 0,
        days: int = 0,
        hours: float = 0,
        minutes: float = 0,
        seconds: float = 0,
        milliseconds: float = 0,
        microseconds: float = 0,
        nanoseconds: int = 0,
        disambiguate: Disambiguate = "raise",
    ) -> ZonedDateTime: ...
    def subtract(
        self,
        *,
        years: int = 0,
        months: int = 0,
        weeks: int = 0,
        days: int = 0,
        hours: float = 0,
        minutes: float = 0,
        seconds: float = 0,
        milliseconds: float = 0,
        microseconds: float = 0,
        nanoseconds: int = 0,
        disambiguate: Disambiguate = "raise",
    ) -> ZonedDateTime: ...
    def __add__(self, delta: Delta) -> ZonedDateTime: ...
    @overload
    def __sub__(self, other: _AwareDateTime) -> TimeDelta: ...
    @overload
    def __sub__(self, other: Delta) -> ZonedDateTime: ...

@final
class LocalSystemDateTime(_AwareDateTime):
    def __init__(
        self,
        year: int,
        month: int,
        day: int,
        hour: int = 0,
        minute: int = 0,
        second: int = 0,
        *,
        nanosecond: int = 0,
        disambiguate: Disambiguate = "raise",
    ) -> None: ...
    @property
    def offset(self) -> TimeDelta: ...
    @classmethod
    def now(cls) -> LocalSystemDateTime: ...
    @classmethod
    def from_timestamp(cls, i: int, /) -> LocalSystemDateTime: ...
    @classmethod
    def from_timestamp_millis(cls, i: int, /) -> LocalSystemDateTime: ...
    @classmethod
    def from_timestamp_nanos(cls, i: int, /) -> LocalSystemDateTime: ...
    @classmethod
    def from_py_datetime(cls, d: _datetime, /) -> LocalSystemDateTime: ...
    @classmethod
    def parse_common_iso(cls, s: str, /) -> LocalSystemDateTime: ...
    def exact_eq(self, other: LocalSystemDateTime, /) -> bool: ...
    def replace(
        self,
        *,
        year: int | _UNSET = ...,
        month: int | _UNSET = ...,
        day: int | _UNSET = ...,
        hour: int | _UNSET = ...,
        minute: int | _UNSET = ...,
        second: int | _UNSET = ...,
        nanosecond: int | _UNSET = ...,
        disambiguate: Disambiguate | _UNSET = ...,
    ) -> LocalSystemDateTime: ...
    def replace_date(
        self, d: Date, /, *, disambiguate: Disambiguate = "raise"
    ) -> LocalSystemDateTime: ...
    def replace_time(
        self, t: Time, /, *, disambiguate: Disambiguate = "raise"
    ) -> LocalSystemDateTime: ...
    def add(
        self,
        *,
        years: int = 0,
        months: int = 0,
        weeks: int = 0,
        days: int = 0,
        hours: float = 0,
        minutes: float = 0,
        seconds: float = 0,
        milliseconds: float = 0,
        microseconds: float = 0,
        nanoseconds: int = 0,
        disambiguate: Disambiguate = "raise",
    ) -> LocalSystemDateTime: ...
    def subtract(
        self,
        *,
        years: int = 0,
        months: int = 0,
        weeks: int = 0,
        days: int = 0,
        hours: float = 0,
        minutes: float = 0,
        seconds: float = 0,
        milliseconds: float = 0,
        microseconds: float = 0,
        nanoseconds: int = 0,
        disambiguate: Disambiguate = "raise",
    ) -> LocalSystemDateTime: ...
    def __add__(self, delta: Delta) -> LocalSystemDateTime: ...
    @overload
    def __sub__(self, other: _AwareDateTime) -> TimeDelta: ...
    @overload
    def __sub__(self, other: Delta) -> LocalSystemDateTime: ...

@final
class NaiveDateTime(_DateTime):
    def __init__(
        self,
        year: int,
        month: int,
        day: int,
        hour: int = 0,
        minute: int = 0,
        second: int = 0,
        *,
        nanosecond: int = 0,
    ) -> None: ...
    MIN: ClassVar[NaiveDateTime]
    MAX: ClassVar[NaiveDateTime]
    def assume_utc(self) -> UTCDateTime: ...
    def assume_fixed_offset(
        self, offset: int | TimeDelta, /
    ) -> OffsetDateTime: ...
    def assume_tz(
        self, tz: str, /, *, disambiguate: Disambiguate = "raise"
    ) -> ZonedDateTime: ...
    def assume_local_system(
        self, *, disambiguate: Disambiguate = "raise"
    ) -> LocalSystemDateTime: ...
    @classmethod
    def from_py_datetime(cls, d: _datetime, /) -> NaiveDateTime: ...
    @classmethod
    def parse_common_iso(cls, s: str, /) -> NaiveDateTime: ...
    @classmethod
    def strptime(cls, s: str, fmt: str, /) -> NaiveDateTime: ...
    def replace(
        self,
        *,
        year: int | _UNSET = ...,
        month: int | _UNSET = ...,
        day: int | _UNSET = ...,
        hour: int | _UNSET = ...,
        minute: int | _UNSET = ...,
        second: int | _UNSET = ...,
        nanosecond: int | _UNSET = ...,
    ) -> NaiveDateTime: ...
    def replace_date(self, d: Date) -> NaiveDateTime: ...
    def replace_time(self, t: Time) -> NaiveDateTime: ...
    def add(
        self,
        *,
        years: int = 0,
        months: int = 0,
        weeks: int = 0,
        days: int = 0,
        hours: float = 0,
        minutes: float = 0,
        seconds: float = 0,
        milliseconds: float = 0,
        microseconds: float = 0,
        nanoseconds: int = 0,
    ) -> NaiveDateTime: ...
    def subtract(
        self,
        *,
        years: int = 0,
        months: int = 0,
        weeks: int = 0,
        days: int = 0,
        hours: float = 0,
        minutes: float = 0,
        seconds: float = 0,
        milliseconds: float = 0,
        microseconds: float = 0,
        nanoseconds: int = 0,
    ) -> NaiveDateTime: ...
    def __add__(self, delta: Delta) -> NaiveDateTime: ...
    @overload
    def __sub__(self, other: NaiveDateTime) -> TimeDelta: ...
    @overload
    def __sub__(self, other: Delta) -> NaiveDateTime: ...
    def __lt__(self, other: NaiveDateTime) -> bool: ...
    def __le__(self, other: NaiveDateTime) -> bool: ...
    def __gt__(self, other: NaiveDateTime) -> bool: ...
    def __ge__(self, other: NaiveDateTime) -> bool: ...

@final
class AmbiguousTime(Exception): ...

@final
class SkippedTime(Exception): ...

@final
class InvalidOffset(ValueError): ...

class Weekday(enum.Enum):
    MONDAY = ...
    TUESDAY = ...
    WEDNESDAY = ...
    THURSDAY = ...
    FRIDAY = ...
    SATURDAY = ...
    SUNDAY = ...

MONDAY = Weekday.MONDAY
TUESDAY = Weekday.TUESDAY
WEDNESDAY = Weekday.WEDNESDAY
THURSDAY = Weekday.THURSDAY
FRIDAY = Weekday.FRIDAY
SATURDAY = Weekday.SATURDAY
SUNDAY = Weekday.SUNDAY

def years(i: int) -> DateDelta: ...
def months(i: int) -> DateDelta: ...
def weeks(i: int) -> DateDelta: ...
def days(i: int) -> DateDelta: ...
def hours(i: float) -> TimeDelta: ...
def minutes(i: float) -> TimeDelta: ...
def seconds(i: float) -> TimeDelta: ...
def milliseconds(i: float) -> TimeDelta: ...
def microseconds(i: float) -> TimeDelta: ...
def nanoseconds(i: int) -> TimeDelta: ...
